@@ -8,6 +8,7 @@
 from __future__ import annotations
 
 import sympy as sp
+from sympy.core.basic import _aresame
 from sympy.printing.latex import LatexPrinter
 
 from ampform.sympy import (
@@ -196,7 +197,8 @@ class EnergyDependentWidth(UnevaluatedExpression):
 
     def _hashable_content(self) -> tuple:
         # https://github.com/sympy/sympy/blob/1.10/sympy/core/basic.py#L157-L165
-        return (*self.args, self.phsp_factor, self._name)
+        # phsp_factor is converted to string because of unstable hash for classes
+        return (*super()._hashable_content(), str(self.phsp_factor))
 
     def evaluate(self) -> sp.Expr:
         s, mass0, gamma0, m_a, m_b, angular_momentum, meson_radius = self.args
@@ -221,6 +223,43 @@ class EnergyDependentWidth(UnevaluatedExpression):
         name = Rf"\Gamma{subscript}" if self._name is None else self._name
         return Rf"{name}\left({s}\right)"
 
+    def _eval_subs(self, old, new):
+        # https://github.com/ComPWA/sympy/blob/bd0cf9a/sympy/core/basic.py#L1074-L1104
+        hit = False
+        new_args = list(self.args)
+        for i, arg in enumerate(self.args):
+            if not hasattr(arg, "_eval_subs"):
+                continue
+            arg = arg._subs(old, new)
+            if not _aresame(arg, new_args[i]):
+                hit = True
+                new_args[i] = arg
+        if hit:
+            # pylint: disable=no-value-for-parameter
+            return self.func(*new_args, self.phsp_factor, self._name)
+        return self
+
+    def _xreplace(self, rule):
+        # https://github.com/sympy/sympy/blob/bd0cf9a/sympy/core/basic.py#L1190-L1210
+        if self in rule:
+            return rule[self], True
+        if rule:
+            new_args = []
+            hit = False
+            for a in self.args:
+                _xreplace = getattr(a, "_xreplace", None)
+                if _xreplace is not None:
+                    a_xr = _xreplace(rule)
+                    new_args.append(a_xr[0])
+                    hit |= a_xr[1]
+                else:
+                    new_args.append(a)
+            new_args = tuple(new_args)
+            if hit:
+                # pylint: disable=no-value-for-parameter
+                return self.func(*new_args, self.phsp_factor, self._name), True
+        return self, False
+
 
 def relativistic_breit_wigner(s, mass0, gamma0) -> sp.Expr:
     """Relativistic Breit-Wigner lineshape.
