@@ -170,7 +170,7 @@ class HelicityModel:  # noqa: R701
 
         intensity = self.intensity.evaluate()
         intensity = unfold_poolsums(intensity)
-        return intensity.subs(self.amplitudes)
+        return intensity.xreplace(self.amplitudes)
 
     def rename_symbols(  # noqa: R701
         self, renames: Iterable[tuple[str, str]] | Mapping[str, str]
@@ -206,7 +206,7 @@ class HelicityModel:  # noqa: R701
                 for amp, expr in self.amplitudes.items()
             },
             parameter_defaults={
-                symbol_mapping[par]: value
+                symbol_mapping.get(par, par): value
                 for par, value in self.parameter_defaults.items()
             },
             components={
@@ -214,7 +214,7 @@ class HelicityModel:  # noqa: R701
                 for name, expr in self.components.items()
             },
             kinematic_variables={
-                symbol_mapping[var]: expr.xreplace(symbol_mapping)
+                symbol_mapping.get(var, var): expr.xreplace(symbol_mapping)
                 for var, expr in self.kinematic_variables.items()
             },
         )
